summaryrefslogtreecommitdiff
path: root/include/linux/soc/ti
diff options
context:
space:
mode:
authorPeter Ujfalusi <peter.ujfalusi@ti.com>2020-10-25 12:10:03 -0700
committerSantosh Shilimkar <santosh.shilimkar@oracle.com>2020-11-01 19:37:59 -0800
commit519c5c0c558b529f835c9bb30f9a1eb2034d585c (patch)
treebb6df60a7d28ac6a5955cb556e411ce88dc34c38 /include/linux/soc/ti
parent967a020bd3deddf9a0af73aeb4d4b46d90030937 (diff)
firmware: ti_sci: rm: Add support for second resource range
Sysfw added support for a second range in the resource range API to be able to describe complex allocations mainly for DMA channels. Update the ti_sci part to consider the second range as well. Signed-off-by: Peter Ujfalusi <peter.ujfalusi@ti.com> Signed-off-by: Santosh Shilimkar <santosh.shilimkar@oracle.com>
Diffstat (limited to 'include/linux/soc/ti')
-rw-r--r--include/linux/soc/ti/ti_sci_protocol.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/include/linux/soc/ti/ti_sci_protocol.h b/include/linux/soc/ti/ti_sci_protocol.h
index 6cd537db4d33..9699b260de59 100644
--- a/include/linux/soc/ti/ti_sci_protocol.h
+++ b/include/linux/soc/ti/ti_sci_protocol.h
@@ -197,13 +197,17 @@ struct ti_sci_clk_ops {
/**
* struct ti_sci_resource_desc - Description of TI SCI resource instance range.
* @start: Start index of the resource.
* @num: Number of resources.
* @res_map: Bitmap to manage the allocation of these resources.
*/
struct ti_sci_resource_desc {
u16 start;
u16 num;
+ u16 start_sec;
+ u16 num_sec;
unsigned long *res_map;
};
@@ -197,13 +197,17 @@ struct ti_sci_clk_ops {
/**
* struct ti_sci_resource_desc - Description of TI SCI resource instance range.
- * @start: Start index of the resource.
- * @num: Number of resources.
+ * @start: Start index of the first resource range.
+ * @num: Number of resources in the first range.
+ * @start_sec: Start index of the second resource range.
+ * @num_sec: Number of resources in the second range.
* @res_map: Bitmap to manage the allocation of these resources.
*/